﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Reflection;
using System.Runtime.InteropServices;
using System.Runtime.InteropServices.ComTypes;
using STATSTG = System.Runtime.InteropServices.ComTypes.STATSTG;

namespace Shetab.Packer
{
    /// <remarks>
    /// The <c>ComStream</c> Convert IStream to .NET Stream.
    /// </remarks>
    
    public class ComStream : Stream
    {
        // the managed stream being wrapped
        IStream _istream;
        /// <summary>
        /// Create .NET Stream object from IStream.
        /// </summary>
        /// <param name="stream">An IStream object.</param>
        public ComStream(IStream stream)
        {
            if (stream == null)
                throw new ArgumentNullException("stream");
            
            _istream = stream;
        }

        /// <summary>
        /// Property to get original stream object.
        /// </summary>
        public IStream IStream
        {
            get
            {
                return _istream;
            }
        }

        
        /// <summary>
        /// See Stream documents in MSDN.
        /// </summary>
        public override int Read(byte[] buffer, int offset, int count)
        {
            IntPtr readed = new IntPtr();
            byte[] newBuf = new byte[count];
            _istream.Read(buffer, count, readed);
            Array.Copy(newBuf, buffer, readed.ToInt32());
            return readed.ToInt32();
        }

        /// <summary>
        /// See Stream documents in MSDN.
        /// </summary>
        public override void Write(byte[] buffer, int offset, int count)
        {
            byte[] newBuf = new byte[count];
            Array.Copy(buffer, offset, newBuf, 0, count);
            _istream.Write(newBuf, count, IntPtr.Zero);
        }

        /// <summary>
        /// See Stream documents in MSDN.
        /// </summary>
        public override long Seek(long offset, SeekOrigin origin)
        {
            long position = 0;
            IntPtr address = new IntPtr();
            _istream.Seek(offset, (int)origin, address);
            return position;
        }

        /// <summary>
        /// See Stream documents in MSDN.
        /// </summary>
        public override long Length
        {
            get
            {
                STATSTG statstg;
                _istream.Stat(out statstg, 1 /* STATSFLAG_NONAME*/ );
                return statstg.cbSize;
            }
        }

        /// <summary>
        /// See Stream documents in MSDN.
        /// </summary>
        public override long Position
        {
            get { return Seek(0, SeekOrigin.Current); }
            set { Seek(value, SeekOrigin.Begin); }
        }

        /// <summary>
        /// See Stream documents in MSDN.
        /// </summary>
        public override void SetLength(long value)
        {
            _istream.SetSize(value);
        }

        /// <summary>
        /// See Stream documents in MSDN.
        /// </summary>
        public override void Close()
        {
            _istream.Commit(0);
            _istream = null;
            Marshal.ReleaseComObject(_istream);
        }

        /// <summary>
        /// See Stream documents in MSDN.
        /// </summary>
        public override void Flush()
        {
            _istream.Commit(0);
        }

        /// <summary>
        /// See Stream documents in MSDN.
        /// </summary>
        public override bool CanRead
        {
            get
            {
                try 
	            {	
                    Byte[] test = new Byte[1];
                    Read(test, 0, 0);
                    return true;
	            }
	            catch (Exception)
	            {
                    return false;
	            }
            }
        }

        /// <summary>
        /// See Stream documents in MSDN.
        /// </summary>
        public override bool CanWrite
        {
            get
            {
                try
                {
                    Byte[] test = new Byte[1];
                    Write(test, 0, 0);
                    return true;
                }
                catch (Exception)
                {
                    return false;
                }
            }
        }

        /// <summary>
        /// See Stream documents in MSDN.
        /// </summary>
        public override bool CanSeek
        {
            get
            {
                try
                {
                    Seek(0, 0);
                    return true;
                }
                catch (Exception)
                {
                    return false;
                }
            }
        }
    }
}
